@@ -19,12 +19,10 @@
 /* These are the keywords that will distinguish the start of an extended
    address. */
 
-static char *extended_keywords[] = {
+static const gchar *extended_keywords[] = {
 	"apt", "apartment", "suite", NULL
 };
 
-
-
 static gboolean
 e_address_western_is_line_blank (gchar *line)
 {
@@ -42,8 +40,6 @@ e_address_western_is_line_blank (gchar *line)
 	return blank;
 }
 
-
-
 /* In the array of lines, `lines', we will erase the line at line_num, and
  shift the remaining lines, up to line number num_lines, up one position. */
 
@@ -62,7 +58,6 @@ e_address_western_shift_line (gchar *lines[], gint line_num, gint num_lines)
 	}
 }
 
-
 static void
 e_address_western_remove_blank_lines (gchar *lines[], gint *linecntr)
 {
@@ -84,7 +79,6 @@ e_address_western_remove_blank_lines (gchar *lines[], gint *linecntr)
 	}
 }
 
-
 static gboolean
 e_address_western_is_po_box (gchar *line)
 {
@@ -93,7 +87,6 @@ e_address_western_is_po_box (gchar *line)
 	/* In which phase of processing are we? */
 	enum State { FIRSTCHAR, SECONDCHAR, WHITESPACE } state;
 
-
 	/* If the first two letters of the line are `p' and `o', and these
 	 are in turn followed by whitespace before another letter, then I
 	 will deem the line a representation of a PO Box address. */
@@ -144,12 +137,12 @@ static gboolean
 e_address_western_is_postal (gchar *line)
 {
 	gboolean retval;
-	int cntr;
+	gint cntr;
 
 	if (strchr (line, ',') == NULL)
 		retval = FALSE;  /* No comma. */
 	else {
-		int index;
+		gint index;
 
 		/* Ensure that the first character after the comma is
 		 a letter. */
@@ -190,7 +183,7 @@ e_address_western_extract_po_box (gchar *line)
 	/* Return everything from the beginning of the line to
 	   the end of the first word that contains a number. */
 
-	int index;
+	gint index;
 
 	index = 0;
 	while (!isdigit(line[index]))
@@ -216,7 +209,6 @@ e_address_western_extract_locality (gchar *line)
 		return g_strndup (line, index);
 }
 
-
 /* Whatever resides between the comma and the start of the
   postal code is deemed to be the region. */
 
@@ -255,7 +247,7 @@ e_address_western_extract_region (gchar *line)
 static gchar *
 e_address_western_extract_postal_code (gchar *line)
 {
-	int start, end;
+	gint start, end;
 
 	end = strlen (line) - 1;
 	while (isspace(line[end]))
@@ -362,7 +354,7 @@ e_address_western_parse (const gchar *in_address)
 	/* Convert the newlines at the end of each line (except the last,
 	 because it is already NULL terminated) to NULLs. */
 	for (cntr = 0; cntr < (linecntr - 1); cntr++) {
-		char *p;
+		gchar *p;
 		p = strchr (lines[cntr], '\n');
 		if (p)
 			*p = '\0';
@@ -374,7 +366,7 @@ e_address_western_parse (const gchar *in_address)
 	found_po_box = FALSE;
 	found_postal = FALSE;
 
-   	for (cntr = 0; cntr < linecntr; cntr++)  {
+	for (cntr = 0; cntr < linecntr; cntr++)  {
 		if (e_address_western_is_po_box (lines[cntr])) {
 			if (eaw->po_box == NULL)
 				eaw->po_box = e_address_western_extract_po_box (lines[cntr]);
