@@ -3,7 +3,7 @@
  * Author:
  *   Nat Friedman (nat@ximian.com)
  *
- * Copyright 2000, Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  */
 
 #include <config.h>
@@ -18,7 +18,7 @@ struct _EBookBackendPrivate {
 	GList *clients;
 
 	ESource *source;
-	gboolean loaded, writable, removed;
+	gboolean loaded, writable, removed, online;
 
 	GMutex *views_mutex;
 	EList *views;
@@ -84,9 +84,9 @@ e_book_backend_load_source (EBookBackend           *backend,
 /**
  * e_book_backend_get_source:
  * @backend: An addressbook backend.
- * 
+ *
  * Queries the source that an addressbook backend is serving.
- * 
+ *
  * Return value: ESource for the backend.
  **/
 ESource *
@@ -123,6 +123,7 @@ e_book_backend_open (EBookBackend *backend,
 			book, opid, GNOME_Evolution_Addressbook_Success);
 
 		e_data_book_report_writable (book, backend->priv->writable);
+		e_data_book_report_connection_status (book, backend->priv->online);
 	} else {
 		GNOME_Evolution_Addressbook_CallStatus status =
 			e_book_backend_load_source (backend, e_data_book_get_source (book), only_if_exists);
@@ -131,6 +132,7 @@ e_book_backend_open (EBookBackend *backend,
 
 		if (status == GNOME_Evolution_Addressbook_Success || status == GNOME_Evolution_Addressbook_InvalidServerVersion)
 			e_data_book_report_writable (book, backend->priv->writable);
+			e_data_book_report_connection_status (book, backend->priv->online);
 	}
 
 	g_mutex_unlock (backend->priv->open_mutex);
@@ -172,7 +174,7 @@ void
 e_book_backend_create_contact (EBookBackend *backend,
 			       EDataBook    *book,
 			       guint32       opid,
-			       const char   *vcard)
+			       const gchar   *vcard)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK (book));
@@ -222,7 +224,7 @@ void
 e_book_backend_modify_contact (EBookBackend *backend,
 			       EDataBook    *book,
 			       guint32       opid,
-			       const char   *vcard)
+			       const gchar   *vcard)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK (book));
@@ -247,7 +249,7 @@ void
 e_book_backend_get_contact (EBookBackend *backend,
 			    EDataBook    *book,
 			    guint32       opid,
-			    const char   *id)
+			    const gchar   *id)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK (book));
@@ -272,7 +274,7 @@ void
 e_book_backend_get_contact_list (EBookBackend *backend,
 				 EDataBook    *book,
 				 guint32       opid,
-				 const char   *query)
+				 const gchar   *query)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK (book));
@@ -337,7 +339,7 @@ void
 e_book_backend_get_changes (EBookBackend *backend,
 			    EDataBook    *book,
 			    guint32       opid,
-			    const char   *change_id)
+			    const gchar   *change_id)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK (book));
@@ -364,9 +366,9 @@ void
 e_book_backend_authenticate_user (EBookBackend *backend,
 				  EDataBook    *book,
 				  guint32       opid,
-				  const char   *user,
-				  const char   *passwd,
-				  const char   *auth_method)
+				  const gchar   *user,
+				  const gchar   *passwd,
+				  const gchar   *auth_method)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
 	g_return_if_fail (E_IS_DATA_BOOK (book));
@@ -474,12 +476,21 @@ book_destroy_cb (gpointer data, GObject *where_book_was)
 	e_book_backend_remove_client (backend, (EDataBook *)where_book_was);
 }
 
+static gboolean
+idle_remove_client (gpointer data)
+{
+	EDataBook *book = (EDataBook *) data;
+
+	e_book_backend_remove_client (e_data_book_get_backend (book), book);
+	g_object_unref ((GObject *) book);
+
+	return FALSE;
+}
 static void
 listener_died_cb (gpointer cnx, gpointer user_data)
 {
-	EDataBook *book = E_DATA_BOOK (user_data);
-
-	e_book_backend_remove_client (e_data_book_get_backend (book), book);
+	g_object_ref ((GObject *)user_data);
+	g_idle_add (idle_remove_client, user_data);
 }
 
 static void
@@ -601,7 +612,7 @@ e_book_backend_remove_client (EBookBackend *backend,
 	 */
 	if (!backend->priv->clients)
 		last_client_gone (backend);
-	
+
 	g_mutex_unlock (backend->priv->clients_mutex);
 
 	g_object_unref (backend);
@@ -624,18 +635,18 @@ e_book_backend_has_out_of_proc_clients (EBookBackend *backend)
 
 	if (!backend->priv->clients) {
 		g_mutex_unlock (backend->priv->clients_mutex);
-		
+
 		return FALSE;
 	}
-	
+
 	for (l = backend->priv->clients; l; l = l->next) {
 		if (ORBit_small_get_connection_status (e_data_book_get_listener (l->data)) != ORBIT_CONNECTION_IN_PROC) {
 			g_mutex_unlock (backend->priv->clients_mutex);
-			
+
 			return TRUE;
 		}
 	}
-	
+
 	g_mutex_unlock (backend->priv->clients_mutex);
 
 	/* If we get here, all remaining clients are in proc */
@@ -651,11 +662,11 @@ e_book_backend_has_out_of_proc_clients (EBookBackend *backend)
  *
  * Return value: A string listing the capabilities.
  **/
-char *
+gchar *
 e_book_backend_get_static_capabilities (EBookBackend *backend)
 {
 	g_return_val_if_fail (E_IS_BOOK_BACKEND (backend), NULL);
-	
+
 	g_assert (E_BOOK_BACKEND_GET_CLASS (backend)->get_static_capabilities);
 
 	return E_BOOK_BACKEND_GET_CLASS (backend)->get_static_capabilities (backend);
@@ -706,7 +717,7 @@ gboolean
 e_book_backend_is_writable (EBookBackend *backend)
 {
 	g_return_val_if_fail (E_IS_BOOK_BACKEND (backend), FALSE);
-	
+
 	return backend->priv->writable;
 }
 
@@ -722,7 +733,7 @@ void
 e_book_backend_set_is_writable (EBookBackend *backend, gboolean is_writable)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
-	
+
 	backend->priv->writable = is_writable;
 }
 
@@ -738,7 +749,7 @@ gboolean
 e_book_backend_is_removed (EBookBackend *backend)
 {
 	g_return_val_if_fail (E_IS_BOOK_BACKEND (backend), FALSE);
-	
+
 	return backend->priv->removed;
 }
 
@@ -754,7 +765,7 @@ void
 e_book_backend_set_is_removed (EBookBackend *backend, gboolean is_removed)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
-	
+
 	backend->priv->removed = is_removed;
 }
 
@@ -766,7 +777,7 @@ e_book_backend_set_is_removed (EBookBackend *backend, gboolean is_removed)
  * Sets @backend's online/offline mode to @mode. Mode can be 1 for offline
  * or 2 indicating that it is connected and online.
  **/
-void 
+void
 e_book_backend_set_mode (EBookBackend *backend,
 			 GNOME_Evolution_Addressbook_BookMode  mode)
 {
@@ -774,7 +785,7 @@ e_book_backend_set_mode (EBookBackend *backend,
 
 	g_assert (E_BOOK_BACKEND_GET_CLASS (backend)->set_mode);
 
-        (* E_BOOK_BACKEND_GET_CLASS (backend)->set_mode) (backend,  mode);	
+        (* E_BOOK_BACKEND_GET_CLASS (backend)->set_mode) (backend,  mode);
 
 }
 
@@ -786,11 +797,11 @@ e_book_backend_set_mode (EBookBackend *backend,
  * circumstances (for example before a live backup) and should not be used in
  * normal use.
  */
-void 
+void
 e_book_backend_sync (EBookBackend *backend)
 {
 	g_return_if_fail (E_IS_BOOK_BACKEND (backend));
-	
+
 	if (E_BOOK_BACKEND_GET_CLASS (backend)->sync)
 		(* E_BOOK_BACKEND_GET_CLASS (backend)->sync) (backend);
 }
@@ -805,7 +816,7 @@ e_book_backend_sync (EBookBackend *backend)
  * Return value: A new #GNOME_Evolution_Addressbook_BookChangeItem.
  **/
 GNOME_Evolution_Addressbook_BookChangeItem*
-e_book_backend_change_add_new     (const char *vcard)
+e_book_backend_change_add_new     (const gchar *vcard)
 {
 	GNOME_Evolution_Addressbook_BookChangeItem* new_change = GNOME_Evolution_Addressbook_BookChangeItem__alloc();
 
@@ -825,7 +836,7 @@ e_book_backend_change_add_new     (const char *vcard)
  * Return value: A new #GNOME_Evolution_Addressbook_BookChangeItem.
  **/
 GNOME_Evolution_Addressbook_BookChangeItem*
-e_book_backend_change_modify_new  (const char *vcard)
+e_book_backend_change_modify_new  (const gchar *vcard)
 {
 	GNOME_Evolution_Addressbook_BookChangeItem* new_change = GNOME_Evolution_Addressbook_BookChangeItem__alloc();
 
@@ -845,7 +856,7 @@ e_book_backend_change_modify_new  (const char *vcard)
  * Return value: A new #GNOME_Evolution_Addressbook_BookChangeItem.
  **/
 GNOME_Evolution_Addressbook_BookChangeItem*
-e_book_backend_change_delete_new  (const char *vcard)
+e_book_backend_change_delete_new  (const gchar *vcard)
 {
 	GNOME_Evolution_Addressbook_BookChangeItem* new_change = GNOME_Evolution_Addressbook_BookChangeItem__alloc();
 
@@ -872,9 +883,9 @@ e_book_backend_foreach_view (EBookBackend *backend,
 	while (e_iterator_is_valid (iter)) {
 		view = (EDataBookView*)e_iterator_get (iter);
 
-		bonobo_object_ref (view);
+		e_data_book_view_ref (view);
 		callback (view, user_data);
-		bonobo_object_unref (view);
+		e_data_book_view_unref (view);
 
 		e_iterator_next (iter);
 	}
@@ -883,7 +894,6 @@ e_book_backend_foreach_view (EBookBackend *backend,
 	g_object_unref (views);
 }
 
-
 static void
 view_notify_update (EDataBookView *view, gpointer contact)
 {
@@ -908,7 +918,6 @@ e_book_backend_notify_update (EBookBackend *backend, EContact *contact)
 	e_book_backend_foreach_view (backend, view_notify_update, contact);
 }
 
-
 static void
 view_notify_remove (EDataBookView *view, gpointer id)
 {
@@ -928,12 +937,11 @@ view_notify_remove (EDataBookView *view, gpointer id)
  * another (non-PAS-using) client.
  **/
 void
-e_book_backend_notify_remove (EBookBackend *backend, const char *id)
+e_book_backend_notify_remove (EBookBackend *backend, const gchar *id)
 {
 	e_book_backend_foreach_view (backend, view_notify_remove, (gpointer)id);
 }
 
-
 static void
 view_notify_complete (EDataBookView *view, gpointer unused)
 {
@@ -962,16 +970,16 @@ e_book_backend_notify_complete (EBookBackend *backend)
  *
  * Notifies all backends clients about the current writable state.
  **/
-void 
+void
 e_book_backend_notify_writable (EBookBackend *backend, gboolean is_writable)
 {
 	EBookBackendPrivate *priv;
 	GList *clients;
-	
+
 	priv = backend->priv;
 	priv->writable = is_writable;
 	g_mutex_lock (priv->clients_mutex);
-	
+
 	for (clients = priv->clients; clients != NULL; clients = g_list_next (clients))
 		e_data_book_report_writable (E_DATA_BOOK (clients->data), is_writable);
 
@@ -987,15 +995,16 @@ e_book_backend_notify_writable (EBookBackend *backend, gboolean is_writable)
  * Notifies clients of @backend's connection status indicated by @is_online.
  * Meant to be used by backend implementations.
  **/
-void 
+void
 e_book_backend_notify_connection_status (EBookBackend *backend, gboolean is_online)
 {
 	EBookBackendPrivate *priv;
 	GList *clients;
-	
+
 	priv = backend->priv;
+	priv->online = is_online;
 	g_mutex_lock (priv->clients_mutex);
-	
+
 	for (clients = priv->clients; clients != NULL; clients = g_list_next (clients))
 		e_data_book_report_connection_status (E_DATA_BOOK (clients->data), is_online);
 
@@ -1014,10 +1023,10 @@ e_book_backend_notify_auth_required (EBookBackend *backend)
 {
 	EBookBackendPrivate *priv;
 	GList *clients;
-	
+
 	priv = backend->priv;
 	g_mutex_lock (priv->clients_mutex);
-	
+
 	for (clients = priv->clients; clients != NULL; clients = g_list_next (clients))
 		e_data_book_report_auth_required (E_DATA_BOOK (clients->data));
 	g_mutex_unlock (priv->clients_mutex);
@@ -1030,6 +1039,7 @@ e_book_backend_init (EBookBackend *backend)
 
 	priv          = g_new0 (EBookBackendPrivate, 1);
 	priv->clients = NULL;
+	priv->source = NULL;
 	priv->views   = e_list_new((EListCopyFunc) NULL, (EListFreeFunc) NULL, NULL);
 	priv->open_mutex = g_mutex_new ();
 	priv->clients_mutex = g_mutex_new ();
@@ -1053,7 +1063,10 @@ e_book_backend_dispose (GObject *object)
 			backend->priv->views = NULL;
 		}
 
-		g_object_unref (backend->priv->source);
+		if (backend->priv->source) {
+			g_object_unref (backend->priv->source);
+			backend->priv->source = NULL;
+		}
 
 		g_mutex_free (backend->priv->open_mutex);
 		g_mutex_free (backend->priv->clients_mutex);
