@@ -1,6 +1,6 @@
 /* Evolution calendar - Live search query listener implementation
  *
- * Copyright (C) 2001 Ximian, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * Author: Federico Mena-Quintero <federico@ximian.com>
  *
@@ -54,7 +54,7 @@ struct _ECalViewListenerClass {
 	void (*objects_added) (ECalViewListener *listener, GList *objects);
 	void (*objects_modified) (ECalViewListener *listener, GList *objects);
 	void (*objects_removed) (ECalViewListener *listener, GList *uids);
-	void (*view_progress) (ECalViewListener *listener, const char *message, int percent);
+	void (*view_progress) (ECalViewListener *listener, const gchar *message, gint percent);
 	void (*view_done) (ECalViewListener *listener, ECalendarStatus status);
 };
 
