@@ -31,9 +31,9 @@
 
 G_BEGIN_DECLS
 
-pid_t camel_process_fork (const char *path, char **argv, int *infd, int *outfd, int *errfd, CamelException *ex);
+pid_t camel_process_fork (const gchar *path, gchar **argv, gint *infd, gint *outfd, gint *errfd, CamelException *ex);
 
-int camel_process_wait (pid_t pid);
+gint camel_process_wait (pid_t pid);
 
 G_END_DECLS
 
