@@ -1,13 +1,13 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /* camel-groupwise-store.h : class for an groupwise store */
 
-/* 
+/*
  * Authors: Sivaiah Nallagatla <snallagatla@novell.com>
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of version 2 of the GNU Lesser General Public 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -21,7 +21,6 @@
  * USA
  */
 
-
 #ifndef CAMEL_GROUPWISE_STORE_H
 #define CAMEL_GROUPWISE_STORE_H 1
 
@@ -50,32 +49,30 @@ struct _CamelGroupwiseStore {
 
 	struct _CamelGroupwiseStoreSummary *summary;
 
-	char *root_container;
+	gchar *root_container;
 	CamelGroupwiseStorePrivate *priv;
 	CamelFolder *current_folder;
-	
+
 	/* the parameters field is not to be included not. probably for 2.6*/
 	/*guint32 parameters;*/
 	time_t refresh_stamp;
 	guint list_loaded;
 };
 
-
 struct _CamelGroupwiseStoreClass {
 	CamelOfflineStoreClass parent_class;
 };
 
-
 /* Standard Camel function */
 CamelType camel_groupwise_store_get_type (void);
-char * groupwise_get_name(CamelService *service, gboolean brief);
+gchar * groupwise_get_name(CamelService *service, gboolean brief);
 
 /*IMplemented*/
-const char *camel_groupwise_store_container_id_lookup (CamelGroupwiseStore *gw_store, const char *folder_name);
-const char *camel_groupwise_store_folder_lookup (CamelGroupwiseStore *gw_store, const char *container_id);
+const gchar *camel_groupwise_store_container_id_lookup (CamelGroupwiseStore *gw_store, const gchar *folder_name);
+const gchar *camel_groupwise_store_folder_lookup (CamelGroupwiseStore *gw_store, const gchar *container_id);
 EGwConnection *cnc_lookup (CamelGroupwiseStorePrivate *priv);
-char *storage_path_lookup (CamelGroupwiseStorePrivate *priv);
-const char *groupwise_base_url_lookup (CamelGroupwiseStorePrivate *priv);
+gchar *storage_path_lookup (CamelGroupwiseStorePrivate *priv);
+const gchar *groupwise_base_url_lookup (CamelGroupwiseStorePrivate *priv);
 CamelFolderInfo * create_junk_folder (CamelStore *store);
 gboolean camel_groupwise_store_connected (CamelGroupwiseStore *store, CamelException *ex);
 void gw_store_reload_folder (CamelGroupwiseStore *store, CamelFolder *folder, guint32 flags, CamelException *ex);
