@@ -4,7 +4,7 @@
 /*
  *  Author: Harish Krishnaswamy (kharish@novell.com)
  *
- *  Copyright 2005 Novell, Inc. (www.novell.com)
+ *  Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
@@ -17,8 +17,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -37,12 +37,11 @@
 #include "camel-session.h"
 #include "camel-url.h"
 
-static void add_hash (guint *hash, char *s);
+static void add_hash (guint *hash, gchar *s);
 static guint hula_url_hash (gconstpointer key);
-static gint check_equal (char *s1, char *s2);
+static gint check_equal (gchar *s1, gchar *s2);
 static gint hula_url_equal (gconstpointer a, gconstpointer b);
 
-
 static CamelProviderConfEntry hula_conf_entries[] = {
 	/* override the labels/defaults of the standard settings */
 	{ CAMEL_PROVIDER_CONF_SECTION_START, "mailcheck", NULL,
@@ -66,13 +65,12 @@ static CamelProviderConfEntry hula_conf_entries[] = {
 	{ CAMEL_PROVIDER_CONF_ENTRY, "namespace", "override_namespace",
 	  N_("Namespace") },
 	{ CAMEL_PROVIDER_CONF_SECTION_END },
-	
+
 	{ CAMEL_PROVIDER_CONF_END }
 	/* revisit each options in other providers (incl. authdomain) for
 	 * relevancy - harish*/
 };
 
-
 static CamelProvider hula_provider = {
 	"hula",
 	N_("Hula"),
@@ -93,15 +91,15 @@ static CamelProvider hula_provider = {
 
 static CamelServiceAuthType camel_hula_password_authtype = {
 	N_("Password"),
-	
+
 	N_("This option will connect to the Hula server using a "
 	   "plaintext password."),
-	
+
 	"",
 	TRUE
 };
 
-static int
+static gint
 hula_auto_detect_cb (CamelURL *url, GHashTable **auto_detected,
 			 CamelException *ex)
 {
@@ -126,16 +124,14 @@ camel_provider_module_init(void)
 	hula_provider.auto_detect = hula_auto_detect_cb;
 	hula_provider.authtypes = g_list_prepend (hula_provider.authtypes, &camel_hula_password_authtype);
 	hula_provider.translation_domain = GETTEXT_PACKAGE;
-	
+
 	hula_provider.object_types[CAMEL_PROVIDER_STORE] = imap_provider->object_types [CAMEL_PROVIDER_STORE];
-	 
-	
+
 	camel_provider_register (&hula_provider);
 }
 
-
 static void
-add_hash (guint *hash, char *s)
+add_hash (guint *hash, gchar *s)
 {
 	if (s)
 		*hash ^= g_str_hash(s);
@@ -148,15 +144,14 @@ hula_url_hash (gconstpointer key)
 	guint hash = 0;
 
 	add_hash (&hash, u->user);
-	add_hash (&hash, u->authmech);
 	add_hash (&hash, u->host);
 	hash ^= u->port;
-	
+
 	return hash;
 }
 
 static gint
-check_equal (char *s1, char *s2)
+check_equal (gchar *s1, gchar *s2)
 {
 	if (s1 == NULL) {
 		if (s2 == NULL)
@@ -164,7 +159,7 @@ check_equal (char *s1, char *s2)
 		else
 			return FALSE;
 	}
-	
+
 	if (s2 == NULL)
 		return FALSE;
 
@@ -175,10 +170,9 @@ static gint
 hula_url_equal (gconstpointer a, gconstpointer b)
 {
 	const CamelURL *u1 = a, *u2 = b;
-	
+
 	return check_equal (u1->protocol, u2->protocol)
 		&& check_equal (u1->user, u2->user)
-		&& check_equal (u1->authmech, u2->authmech)
 		&& check_equal (u1->host, u2->host)
 		&& u1->port == u2->port;
 }
