@@ -31,26 +31,25 @@
 
 static GMainLoop *main_loop = NULL;
 static ESourceList *list = NULL;
-static int idle_dump_id = 0;
-
+static gint idle_dump_id = 0;
 
 /* Options.  */
 
 static gboolean listen = FALSE;
 static gboolean dump = FALSE;
-static char *key_arg = "/apps/evolution/test/source_list";
-static char *source_arg = NULL;
-static char *group_arg = NULL;
-static char *add_group_arg = NULL;
-static char *add_source_arg = NULL;
-static char *remove_group_arg = NULL;
-static char *remove_source_arg = NULL;
-static char *property_arg = NULL;
-static char *set_name_arg = NULL;
-static char *set_base_uri_arg = NULL;
-static char *set_relative_uri_arg = NULL;
-static char *set_color_arg = NULL;
-static char *set_value_arg = NULL;
+static gchar *key_arg = (gchar *) "/apps/evolution/test/source_list";
+static gchar *source_arg = NULL;
+static gchar *group_arg = NULL;
+static gchar *add_group_arg = NULL;
+static gchar *add_source_arg = NULL;
+static gchar *remove_group_arg = NULL;
+static gchar *remove_source_arg = NULL;
+static gchar *property_arg = NULL;
+static gchar *set_name_arg = NULL;
+static gchar *set_base_uri_arg = NULL;
+static gchar *set_relative_uri_arg = NULL;
+static gchar *set_color_arg = NULL;
+static gchar *set_value_arg = NULL;
 static gboolean unset_value = FALSE;
 static gboolean unset_color = FALSE;
 
@@ -90,7 +89,7 @@ dump_property (const gchar *prop, const gchar *value)
 static void
 dump_source (ESource *source)
 {
-	char *uri = e_source_get_uri (source);
+	gchar *uri = e_source_get_uri (source);
 	const gchar *color_spec;
 
 	g_print ("\tSource %s\n", e_source_peek_uid (source));
@@ -125,7 +124,8 @@ dump_group (ESourceGroup *group)
 
 		if (e_source_peek_group (source) != group)
 			g_warning ("\t\t** ERROR ** parent pointer is %p, should be %p",
-				   e_source_peek_group (source), group);
+				   (gpointer) e_source_peek_group (source),
+				   (gpointer) group);
 	}
 }
 
@@ -144,9 +144,8 @@ dump_list (void)
 		dump_group (E_SOURCE_GROUP (p->data));
 }
 
-
-static int
-idle_dump_callback (void *unused_data)
+static gint
+idle_dump_callback (gpointer unused_data)
 {
 	dump_list ();
 	idle_dump_id = 0;
@@ -161,11 +160,10 @@ dump_on_idle (void)
 		idle_dump_id = g_idle_add (idle_dump_callback, NULL);
 }
 
-
 static void
 source_changed_callback (ESource *source)
 {
-	static int count = 0;
+	static gint count = 0;
 
 	g_print ("** Event: source \"%s\" changed (%d)\n", e_source_peek_name (source), ++count);
 
@@ -175,7 +173,7 @@ source_changed_callback (ESource *source)
 static void
 group_changed_callback (ESourceGroup *group)
 {
-	static int count = 0;
+	static gint count = 0;
 
 	g_print ("** Event: group \"%s\" changed (%d)\n", e_source_group_peek_name (group), ++count);
 
@@ -185,14 +183,13 @@ group_changed_callback (ESourceGroup *group)
 static void
 list_changed_callback (ESourceGroup *group)
 {
-	static int count = 0;
+	static gint count = 0;
 
 	g_print ("** Event: list changed (%d)\n", ++count);
 
 	dump_on_idle ();
 }
 
-
 static void
 connect_source (ESource *source)
 {
@@ -246,12 +243,11 @@ disconnect_source (ESource *source)
 	g_object_unref (source);
 }
 
-
 static void
 source_added_callback (ESourceGroup *group,
 		       ESource *source)
 {
-	static int count = 0;
+	static gint count = 0;
 
 	g_print ("** Event: source \"%s\" added (%d)\n", e_source_peek_name (source), ++count);
 
@@ -263,7 +259,7 @@ static void
 source_removed_callback (ESourceGroup *group,
 			 ESource *source)
 {
-	static int count = 0;
+	static gint count = 0;
 
 	g_print ("** Event: source \"%s\" removed (%d)\n", e_source_peek_name (source), ++count);
 
@@ -275,7 +271,7 @@ static void
 group_added_callback (ESourceList *list,
 		      ESourceGroup *group)
 {
-	static int count = 0;
+	static gint count = 0;
 
 	g_print ("** Event: group \"%s\" added (%d)\n", e_source_group_peek_name (group), ++count);
 
@@ -287,7 +283,7 @@ static void
 group_removed_callback (ESourceList *list,
 			ESourceGroup *group)
 {
-	static int count = 0;
+	static gint count = 0;
 
 	g_print ("** Event: group \"%s\" removed (%d)\n", e_source_group_peek_name (group), ++count);
 
@@ -295,9 +291,8 @@ group_removed_callback (ESourceList *list,
 	dump_on_idle ();
 }
 
-
-static int
-on_idle_do_stuff (void *unused_data)
+static gint
+on_idle_do_stuff (gpointer unused_data)
 {
 	GConfClient *client = gconf_client_get_default ();
 	ESourceGroup *new_group = NULL;
@@ -535,9 +530,8 @@ on_idle_do_stuff (void *unused_data)
 	return FALSE;
 }
 
-
-int
-main (int argc, char **argv)
+gint
+main (gint argc, gchar **argv)
 {
 	GOptionContext *context;
 	GError *error = NULL;
