@@ -1,10 +1,10 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /* e-source-selector-dialog.c
  *
- * Copyright (C) 2004  Novell, Inc.
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
+ * modify it under the terms of the GNU Lesser General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
  *
@@ -13,10 +13,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  * Author: Rodrigo Moya <rodrigo@novell.com>
  */
@@ -27,12 +27,6 @@
 
 #include <glib/gi18n-lib.h>
 #include <glib-object.h>
-#include <gtk/gtkhbox.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkvbox.h>
 #include "e-source-selector.h"
 #include "e-source-selector-dialog.h"
 
@@ -92,18 +86,23 @@ static void
 e_source_selector_dialog_init (ESourceSelectorDialog *dialog)
 {
 	ESourceSelectorDialogPrivate *priv;
+	GtkWidget *action_area;
+	GtkWidget *content_area;
 
 	priv = g_new0 (ESourceSelectorDialogPrivate, 1);
 	priv->selected_source = NULL;
 	dialog->priv = priv;
 
+	action_area = gtk_dialog_get_action_area (GTK_DIALOG (dialog));
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
 	/* prepare the dialog */
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Select destination"));
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 320, 240);
 	gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
 	gtk_widget_ensure_style (GTK_WIDGET (dialog));
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), 0);
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)->action_area), 12);
+	gtk_container_set_border_width (GTK_CONTAINER (content_area), 0);
+	gtk_container_set_border_width (GTK_CONTAINER (action_area), 12);
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 				GTK_STOCK_OK, GTK_RESPONSE_OK,
@@ -141,14 +140,17 @@ static GtkWidget *
 setup_dialog (GtkWindow *parent, ESourceSelectorDialog *dialog, ESourceList *source_list)
 {
 	GtkWidget *vbox, *label, *scroll, *hbox, *spacer;
-	char *label_text;
+	GtkWidget *content_area;
+	gchar *label_text;
 	ESourceSelectorDialogPrivate *priv = dialog->priv;
 
 	priv->source_list = g_object_ref (source_list);
 
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
+
 	vbox = gtk_vbox_new (FALSE, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 12);
-	gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), vbox);
+	gtk_container_add (GTK_CONTAINER (content_area), vbox);
 	gtk_widget_show (vbox);
 
 	label_text = g_strdup_printf ("<b>%s</b>", _("_Destination"));
@@ -210,6 +212,52 @@ e_source_selector_dialog_new (GtkWindow *parent, ESourceList *source_list)
 	return setup_dialog (parent, dialog, source_list);
 }
 
+/**
+ * e_source_selector_dialog_select_default_source:
+ * @dialog: An #ESourceSelectorDialog widget.
+ *
+ * Selects default source in the dialog.
+ *
+ * Return value: Whether found any default source.
+ **/
+gboolean
+e_source_selector_dialog_select_default_source (ESourceSelectorDialog *dialog)
+{
+	ESourceSelectorDialogPrivate *priv;
+
+	g_return_val_if_fail (E_IS_SOURCE_SELECTOR_DIALOG (dialog), FALSE);
+
+	priv = dialog->priv;
+
+	if (priv->source_list) {
+		ESource *default_source = NULL;
+		GSList *groups, *g;
+
+		groups = e_source_list_peek_groups (priv->source_list);
+		for (g = groups; g != NULL && !default_source; g = g->next) {
+			ESourceGroup *group = E_SOURCE_GROUP (g->data);
+			GSList *sources, *s;
+
+			sources = e_source_group_peek_sources (group);
+
+			for (s = sources; s != NULL && !default_source; s = s->next) {
+				ESource *source = E_SOURCE (s->data);
+
+				if (source && e_source_get_property (source, "default"))
+					default_source = source;
+			}
+
+		}
+
+		if (default_source)
+			e_source_selector_set_primary_selection (E_SOURCE_SELECTOR (priv->source_selector), default_source);
+
+		return default_source != NULL;
+	}
+
+	return FALSE;
+}
+
 /**
  * e_source_selector_dialog_peek_primary_selection:
  * @dialog: An #ESourceSelectorDialog widget.
